@@ -3,12 +3,12 @@ use std::{
     sync::Arc,
 };
 
-use crate::{Catalog, InjectionError};
+use crate::*;
 
 /////////////////////////////////////////////////////////////////////////////////////////
 
-/// Builders are responsible for resolving dependencies,
-/// delegating lifetime management to scopes, and creating new instances
+/// Builders are responsible for resolving dependencies and creating new instances of a certain type.
+/// Builders typically create new instances for every call, delegating the lifetime management to [`Scope`]s,
 pub trait Builder: Send + Sync {
     fn instance_type_id(&self) -> TypeId;
     fn instance_type_name(&self) -> &'static str;
@@ -19,15 +19,42 @@ pub trait TypedBuilder<T: Send + Sync>: Builder {
     fn get(&self, cat: &Catalog) -> Result<Arc<T>, InjectionError>;
 }
 
-/// Allows catalog.add to accept both impl types with associated builder and custom builders
+/// Allows [`CatalogBuilder::add()`] to accept both impl types with associated builder and custom builders
 pub trait BuilderLike {
     type Builder: Builder;
-    fn register(cat: &mut Catalog);
+    fn register(cat: &mut CatalogBuilder);
     fn builder() -> Self::Builder;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////
 
+/// Used to create an instance of a default builder for a component.
+/// This instance can be then be parametrized before adding it into the [`CatalogBuilder`].
+///
+/// # Examples
+///
+/// ```
+/// use dill::*;
+///
+/// #[component]
+/// struct ConnectionPool {
+///     host: String,
+///     port: u16,
+/// }
+///
+/// let catalog = CatalogBuilder::new()
+///     .add_builder(
+///         builder_for::<ConnectionPool>()
+///             .with_host("foo".to_owned())
+///             .with_port(8080)
+///     );
+/// ```
+pub fn builder_for<B: BuilderLike>() -> B::Builder {
+    B::builder()
+}
+
+/////////////////////////////////////////////////////////////////////////////////////////
+
 pub struct Prebuilt<T>
 where
     T: 'static + Send + Sync,
@@ -39,11 +66,15 @@ impl<T> Prebuilt<T>
 where
     T: 'static + Send + Sync,
 {
-    pub fn new(value: T) -> Self {
+    pub fn from_value(value: T) -> Self {
         Self {
             value: Arc::new(value),
         }
     }
+
+    pub fn from_shared(value: Arc<T>) -> Self {
+        Self { value }
+    }
 }
 
 impl<T> Builder for Prebuilt<T>
@@ -74,6 +105,7 @@ where
 
 /////////////////////////////////////////////////////////////////////////////////////////
 
+// TODO: Implement Builder trait for any `Fn() -> T` without wrapping?
 pub struct Factory<Fct, Impl>
 where
     Fct: Fn() -> Impl,
