@@ -7,7 +7,7 @@ pub enum InjectionError {
     #[error("Unregistered type")]
     Unregistered(UnregisteredTypeError),
     #[error("Ambiguous type")]
-    Ambiguous,
+    Ambiguous(AmbiguousTypeError),
 }
 
 impl InjectionError {
@@ -17,6 +17,13 @@ impl InjectionError {
             type_name: type_name::<Iface>(),
         })
     }
+
+    pub fn ambiguous<Iface: 'static + ?Sized>() -> Self {
+        Self::Ambiguous(AmbiguousTypeError {
+            type_id: TypeId::of::<Iface>(),
+            type_name: type_name::<Iface>(),
+        })
+    }
 }
 
 #[derive(Error, Debug, Clone, PartialEq, Eq)]
@@ -25,3 +32,10 @@ pub struct UnregisteredTypeError {
     type_id: TypeId,
     type_name: &'static str,
 }
+
+#[derive(Error, Debug, Clone, PartialEq, Eq)]
+#[error("Ambiguous type: ${type_name}")]
+pub struct AmbiguousTypeError {
+    type_id: TypeId,
+    type_name: &'static str,
+}
